# September 28, 2021

**Date:** September 28, 2021, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2021-09-28/8:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)**

**[YouTube link](https://youtu.be/BZLM_clyHwo)** 

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html).
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Loïc** Extensions for HDF5 files
    * Release 1.0.0 for [jupyterlab-hdf5](https://github.com/jupyterlab/jupyterlab-hdf5) bringing support for JupyterLab 3
        * :thumbsup: Thank You!!!
  * Release 0.10.0 for [jupyterlab-h5web](https://github.com/silx-kit/jupyterlab-h5web) removing big files limitation

## Agenda Items

* **Angus** would like to introduce the prototype [`jupyterlab-imarkdown`](https://github.com/agoose77/jupyterlab-imarkdown/) and discuss its wider implications.
* **Rollin** would like to share Jupyter security documentation review from Trusted CI
    * The review doc from Kay Avila at Trusted CI: https://bit.ly/3ED0zbN
    * https://discourse.jupyter.org/t/jupyter-security-related-documentation/10921
    * Will be discussed at next few security meetings (every other Friday, see the [Jupyter calendar](https://discourse.jupyter.org/t/jupyter-community-calendar/2485) for event)
    * (Background: https://blog.jupyter.org/trusted-ci-cybersecurity-engagement-with-jupyter-859a5f5d7201)
* **Rick** would like to introduce a new extension and get feedback
* **Theodore** looking for links for good jupyter lab widgets dev tutorials and examples

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.
- https://kidpix.app/

## Attendees 

|      Name      |        Institution        |           GitHub Handle           |
|----------------|---------------------------|-----------------------------------|
| Angus Hollands |      U Birmingham         |             @agoose77             |
| Rick McGeer    |       engageLively        |             @rickmcgeer           |
| Chris Sewell         |     EPFL / EBP       | @chrisjsewell |
| Sarah Gibson         | 2i2c           | @sgibson91
| Simon Li | University of Dundee | @manics
| Rollin Thomas  | NERSC | @rcthomas |
| Wayne Decatur | Upstate Medical University | @fomightez |
| Karla Spuldaro | IBM | @karlaspuldaro |
| Joyce Er | Microsoft | @joyceerhl |
| Pete Blois     | Google                    | @blois           |
| Tony Fast | Quansight | @tonyfast |
| Alex Bozarth | IBM | @ajbozarth |
| Theodore Aptekarev | 🚀 | @piiq |
| Loïc Huder | ESRF | @loichuder |
| Luciano Resende | IBM | @lresende |
| Jessica Xu | Quansight | @jess-x |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |

Plus 5 others.